@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.002_001'; # TRIAL VERSION
+our $VERSION = '0.002_002'; # TRIAL VERSION
 
 use YAML::PP::Render;
 
@@ -29,7 +29,6 @@ sub set_receiver {
     else {
         $callback = sub {
             my ($self, $event, $info) = @_;
-            $event = lc $event;
             return $receiver->$event($info);
         };
     }
@@ -42,23 +41,11 @@ sub reader {
         return $self->{reader};
     }
 
-    {
-        package
-         Reader;
-        sub read {
-            $_[0]->{input};
-        }
-        sub new {
-            my ($class, %args) = @_;
-            return bless { %args }, $class;
-        }
-    }
+    my $input = $self->{input} // die "No input";
 
-    my $input = $self->{input} // die;
-
-    return Reader->new(input => $input);
+    require YAML::PP::Reader;
+    return YAML::PP::Reader->new(input => $input);
 }
-sub input { return($_[0]->{receiver} // die "No input") }
 sub callback { return $_[0]->{callback} }
 sub set_callback { $_[0]->{callback} = $_[1] }
 sub yaml { return $_[0]->{yaml} }
@@ -603,7 +590,7 @@ sub parse_next {
 sub res_to_event {
     my ($self, $res) = @_;
     if (defined(my $alias = $res->{alias})) {
-        $self->event([ alias => { content => $alias }]);
+        $self->event([ ALI => { content => $alias }]);
     }
     elsif (defined(my $value = $res->{value})) {
         my $style = $res->{style} // ':';
@@ -1053,7 +1040,7 @@ sub event_value {
         $self->set_anchor(undef);
         $info{anchor} = $anchor;
     }
-    $self->event([ value => { content => $value, %info, }]);
+    $self->event([ VAL => { content => $value, %info, }]);
 }
 
 sub push_events {
@@ -1076,6 +1063,15 @@ sub pop_events {
     }
 }
 
+my %event_to_method = (
+    MAP => 'mapping',
+    SEQ => 'sequence',
+    DOC => 'document',
+    STR => 'stream',
+    VAL => 'value',
+    ALI => 'alias',
+);
+
 sub begin {
     my ($self, $event, $offset, @content) = @_;
     my $event_name = $event;
@@ -1095,7 +1091,8 @@ sub begin {
         }
     }
     TRACE and $self->debug_event("------------->> BEGIN $event ($offset) @content");
-    $self->callback->($self, "begin_" . (lc $event_name) => { %info, content => $content[0] });
+    $self->callback->($self, "begin_" . $event_to_method{ $event_name }
+        => { %info, content => $content[0] });
     $self->push_events($event, $offset);
     TRACE and $self->debug_events;
 }
@@ -1105,7 +1102,8 @@ sub end {
     $self->pop_events($event);
     TRACE and $self->debug_event("-------------<< END   $event @{[$content//'']}");
     return if $event eq 'END';
-    $self->callback->($self, "end_" . (lc $event), => { type => $event, content => $content });
+    $self->callback->($self, "end_" . $event_to_method{ $event }
+        => { type => $event, content => $content });
     if ($event eq 'DOC') {
         $self->set_tagmap({
             '!!' => "tag:yaml.org,2002:",
@@ -1118,7 +1116,7 @@ sub event {
     TRACE and $self->debug_event("------------- EVENT @{[ $self->event_to_test_suite($event)]}");
 
     my ($type, $info) = @$event;
-    $self->callback->($self, lc $type, $info);
+    $self->callback->($self, $event_to_method{ $type }, $info);
 }
 
 sub event_to_test_suite {
